==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GridGroupDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridGroupDescriptionsChangedEventArgsDescription } from "./GridGroupDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridGroupDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridGroupDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupDescriptions", "Collection:ColumnGroupDescription:ColumnGroupDescriptionCollection:ColumnGroupDescription");
        }
        static d(a) {
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridGroupDescriptionsChangedEventArgs", () => new GridGroupDescriptionsChangedEventArgsDescription());
            a.z("GridGroupDescriptionsChangedEventArgs", GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, 'GridGroupDescriptionsChangedEventArgsDescriptionMetadata');
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridGroupDescriptionsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridGroupDescriptionsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridGroupDescriptionsChangedEventArgsDescription } from "./GridGroupDescriptionsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridGroupDescriptionsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridGroupDescriptionsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a == null) {
                GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridGroupDescriptionsChangedEventArgsDescriptionMetadata.c(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupDescriptions", "Collection:ColumnGroupDescription:ColumnGroupDescriptionCollection:ColumnGroupDescription");
        }
        static d(a) {
            GridGroupDescriptionsChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridGroupDescriptionsChangedEventArgs", () => new GridGroupDescriptionsChangedEventArgsDescription());
            a.ab("GridGroupDescriptionsChangedEventArgs", GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridGroupDescriptionsChangedEventArgsDescriptionMetadata, 'GridGroupDescriptionsChangedEventArgsDescriptionMetadata');
    GridGroupDescriptionsChangedEventArgsDescriptionMetadata.a = null;
    return GridGroupDescriptionsChangedEventArgsDescriptionMetadata;
})();
